.. image:: doc/_static/pandalone_logo.png
   :width: 300 px
   :align: center

######################################################
Process data-trees with reconfigurable-paths in Python
######################################################
|pypi-ver| |travis-status| |appveyor-status| |cover-status| |docs-status| \
|dependencies| |downloads-count| |github-issues| |python-ver| |proj-license|


.. include:: ../README.rst
    :start-after:  :align: center
    :end-before: _end-opening:

.. toctree::
    :numbered:

    intro
    install
    usage
    contribute
    reference
    CHANGES
    indices

.. include:: ../README.rst
    :start-after: _glossary:
